classdef adodb < handle
% adodb is a class to query database using ADODB
% 
% The main method of adodb is adodb.query
%   [res, isSuccess] = adodb.query(sql, ado_connection_string), query the
%   database which is specified by ado_connection_string.
%   
%   ado_connection_string could be a connection string, or just provide
%   following information in 5*1 cells or a struct
%      type: connection type - currently supported: 'Access','SQL','Oracle'
%      server: name of server - not required for Access connection
%      databasename: name of database - not required for Oracle connection
%      user, user id to login - added to connection string if provided
%      password: password to login - added to connection string if provided
% 
% adodb.queryvar is an alternative of query when you only need the first 
% result.  
% 
% usage examples
% 
%   ado = adodb;
%   res = ado.query('select * from sys', ...
%     'Provider=OraOLEDB.Oracle;Data Source=MyOracleDB;User Id=myUsername;Password=myPassword;');
%   res = ado.query(sql, {database_type, server_name_or_ip, ...
%     database_name, user, password});
% 
% See also: adodb/query, adodb/queryvar, adodb/connstr
% 
% Copyright: zhang@zhiqiang.org, 2010
% http://zhiqiang.org/blog/it/use-adodb-in-matlab.html

    properties
        conn
        connStr
        sql
    end
    
    properties (Access = public)
        savedConnectionStrings = containers.Map(...
            {'jydb'}, ...
            {{'sql', '10.1.1.48', 'JYDB', 'inforead', 'readinfo'}});
    end
    
    methods
        % set up a connection object
        function obj = adodb()
            obj.conn = actxserver('ADODB.Connection');
            set(obj.conn,'CursorLocation',3);
            obj.connStr = '';
        end
        
        setconn(obj, connStr, timeout)
        
        res = query(obj, sql, sqlInfo)
        res = queryvar(obj, sql, sqlInfo)
    end
    
    methods (Static = true)
        str = connstr(type, server, databasename, user, password)
    end
end