function str = connstr(type, server, databasename, user, password)
%Returns connection string for ADO OLEDB connection
%
% The inputs could be three formats: the first are five inputs,
% the second are a 5*1 cells, and the third is a struct with
% five fileds.
%
%   str = connstr(type, server, databasename, user, password)
%
%   str = connstr({type, server, databasename, user,
%   password});
%
%   str = connstr(struct('type', 'server', 'databasename',
%   'user', 'password'))
%
% Inputs:
%   type,   connection type - currently supported: 'Access','SQL','Oracle'
%   server,     name of server - not required for Access connection
%   databasename,     name of database - not required for Oracle connection
%   user,    user id - added to connection string if provided
%   password,    password - added to connection string if provided
%
% Output:
%   s,      connection string
%
% Usage:
%   str = adodb.connstr('sql','servername','databasename','userid','password')
%
% See also: adodb, adodb/query, adodb/queryone
%
% Copyright: zhang@zhiqiang.org, 2010
% http://zhiqiang.org/blog/tag/matlab


if iscell(type)
    server = type{2};
    databasename = type{3};
    if numel(type) > 3, user = type{4}; end
    if numel(type) > 4, password = type{5}; end
    type = type{1};
end

if isstruct(type)
    server = type.server;
    databasename = type.databasename;
    if isfield(type, 'user'), user = type.user; end
    if isfield(type, 'password'), password = type.password; end
    type = type.type;
end

if strcmpi('ACCESS',type)
    % Connect to Access database 
    str = 'PROVIDER=Microsoft.Jet.OLEDB.4.0;';
    str = [str 'Data Source=' databasename ';'];
    
elseif strcmpi('SQL', type)
    % Connect to SQL Database
    str = 'Provider=SQLOLEDB;';
    str = [str 'Data Source=' server ';Initial Catalog=' databasename ';'];
    
elseif strcmpi('ORACLE',type)
    % Connect to Oracle Database
    str = 'Provider=OraOLEDB.Oracle;';
    str = [str 'Data Source=' databasename ';'];
else
    str = 'Unknown type';
end

% add uid and pwd if provided
if exist('user', 'var'), str = [str 'User Id=' user ';']; end
if exist('password', 'var'), str = [str 'Password=' password ';']; end